@@ -1,13 +1,10 @@
-from typing import Annotated, Optional
+from typing import Annotated
 
 import pytest
-from dirty_equals import IsDict
 from fastapi import Body, FastAPI
 from fastapi.testclient import TestClient
 from pydantic import BaseModel, Field
 
-from tests.utils import needs_pydanticv2
-
 from .utils import get_body_model_name
 
 app = FastAPI()
@@ -17,12 +14,12 @@ app = FastAPI()
 
 
 @app.post("/optional-str", operation_id="optional_str")
-async def read_optional_str(p: Annotated[Optional[str], Body(embed=True)] = None):
+async def read_optional_str(p: Annotated[str | None, Body(embed=True)] = None):
     return {"p": p}
 
 
 class BodyModelOptionalStr(BaseModel):
-    p: Optional[str] = None
+    p: str | None = None
 
 
 @app.post("/model-optional-str", operation_id="model_optional_str")
@@ -38,27 +35,16 @@ def test_optional_str_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p": {
-                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                    "title": "P",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p": {
+                "anyOf": [{"type": "string"}, {"type": "null"}],
+                "title": "P",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p": {"type": "string", "title": "P"},
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_str_missing():
@@ -72,29 +58,16 @@ def test_model_optional_str_missing():
     client = TestClient(app)
     response = client.post("/model-optional-str")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -125,13 +98,13 @@ def test_optional_str(path: str):
 
 @app.post("/optional-alias", operation_id="optional_alias")
 async def read_optional_alias(
-    p: Annotated[Optional[str], Body(embed=True, alias="p_alias")] = None,
+    p: Annotated[str | None, Body(embed=True, alias="p_alias")] = None,
 ):
     return {"p": p}
 
 
 class BodyModelOptionalAlias(BaseModel):
-    p: Optional[str] = Field(None, alias="p_alias")
+    p: str | None = Field(None, alias="p_alias")
 
 
 @app.post("/model-optional-alias", operation_id="model_optional_alias")
@@ -150,27 +123,16 @@ def test_optional_str_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_alias": {
-                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                    "title": "P Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_alias": {
+                "anyOf": [{"type": "string"}, {"type": "null"}],
+                "title": "P Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_alias": {"type": "string", "title": "P Alias"},
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
 def test_optional_alias_missing():
@@ -184,29 +146,16 @@ def test_model_optional_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
 @pytest.mark.parametrize(
@@ -248,15 +197,13 @@ def test_optional_alias_by_alias(path: str):
 
 @app.post("/optional-validation-alias", operation_id="optional_validation_alias")
 def read_optional_validation_alias(
-    p: Annotated[
-        Optional[str], Body(embed=True, validation_alias="p_val_alias")
-    ] = None,
+    p: Annotated[str | None, Body(embed=True, validation_alias="p_val_alias")] = None,
 ):
     return {"p": p}
 
 
 class BodyModelOptionalValidationAlias(BaseModel):
-    p: Optional[str] = Field(None, validation_alias="p_val_alias")
+    p: str | None = Field(None, validation_alias="p_val_alias")
 
 
 @app.post(
@@ -268,7 +215,6 @@ def read_model_optional_validation_alias(
     return {"p": p.p}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     ["/optional-validation-alias", "/model-optional-validation-alias"],
@@ -277,30 +223,18 @@ def test_optional_validation_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_val_alias": {
-                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                    "title": "P Val Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_val_alias": {
+                "anyOf": [{"type": "string"}, {"type": "null"}],
+                "title": "P Val Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_val_alias": {"type": "string", "title": "P Val Alias"},
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
-@needs_pydanticv2
 def test_optional_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/optional-validation-alias")
@@ -308,37 +242,22 @@ def test_optional_validation_alias_missing():
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 def test_model_optional_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-validation-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     ["/optional-validation-alias", "/model-optional-validation-alias"],
@@ -350,7 +269,6 @@ def test_model_optional_validation_alias_missing_empty_dict(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -365,7 +283,6 @@ def test_optional_validation_alias_by_name(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -390,14 +307,14 @@ def test_optional_validation_alias_by_validation_alias(path: str):
 )
 def read_optional_alias_and_validation_alias(
     p: Annotated[
-        Optional[str], Body(embed=True, alias="p_alias", validation_alias="p_val_alias")
+        str | None, Body(embed=True, alias="p_alias", validation_alias="p_val_alias")
     ] = None,
 ):
     return {"p": p}
 
 
 class BodyModelOptionalAliasAndValidationAlias(BaseModel):
-    p: Optional[str] = Field(None, alias="p_alias", validation_alias="p_val_alias")
+    p: str | None = Field(None, alias="p_alias", validation_alias="p_val_alias")
 
 
 @app.post(
@@ -410,7 +327,6 @@ def read_model_optional_alias_and_validation_alias(
     return {"p": p.p}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -422,30 +338,18 @@ def test_optional_alias_and_validation_alias_schema(path: str):
     openapi = app.openapi()
     body_model_name = get_body_model_name(openapi, path)
 
-    assert app.openapi()["components"]["schemas"][body_model_name] == IsDict(
-        {
-            "properties": {
-                "p_val_alias": {
-                    "anyOf": [{"type": "string"}, {"type": "null"}],
-                    "title": "P Val Alias",
-                },
+    assert app.openapi()["components"]["schemas"][body_model_name] == {
+        "properties": {
+            "p_val_alias": {
+                "anyOf": [{"type": "string"}, {"type": "null"}],
+                "title": "P Val Alias",
             },
-            "title": body_model_name,
-            "type": "object",
-        }
-    ) | IsDict(
-        # TODO: remove when deprecating Pydantic v1
-        {
-            "properties": {
-                "p_val_alias": {"type": "string", "title": "P Val Alias"},
-            },
-            "title": body_model_name,
-            "type": "object",
-        }
-    )
+        },
+        "title": body_model_name,
+        "type": "object",
+    }
 
 
-@needs_pydanticv2
 def test_optional_alias_and_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/optional-alias-and-validation-alias")
@@ -453,37 +357,22 @@ def test_optional_alias_and_validation_alias_missing():
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 def test_model_optional_alias_and_validation_alias_missing():
     client = TestClient(app)
     response = client.post("/model-optional-alias-and-validation-alias")
     assert response.status_code == 422, response.text
-    assert response.json() == IsDict(
-        {
-            "detail": [
-                {
-                    "input": None,
-                    "loc": ["body"],
-                    "msg": "Field required",
-                    "type": "missing",
-                },
-            ],
-        }
-    ) | IsDict(
-        {
-            # TODO: remove when deprecating Pydantic v1
-            "detail": [
-                {
-                    "loc": ["body"],
-                    "msg": "field required",
-                    "type": "value_error.missing",
-                },
-            ],
-        }
-    )
+    assert response.json() == {
+        "detail": [
+            {
+                "input": None,
+                "loc": ["body"],
+                "msg": "Field required",
+                "type": "missing",
+            },
+        ],
+    }
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -498,7 +387,6 @@ def test_model_optional_alias_and_validation_alias_missing_empty_dict(path: str)
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -513,7 +401,6 @@ def test_optional_alias_and_validation_alias_by_name(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
@@ -528,7 +415,6 @@ def test_optional_alias_and_validation_alias_by_alias(path: str):
     assert response.json() == {"p": None}
 
 
-@needs_pydanticv2
 @pytest.mark.parametrize(
     "path",
     [
