@@ -1,4 +1,4 @@
-from typing import Annotated, Optional
+from typing import Annotated
 
 import pytest
 from fastapi import FastAPI, Header
@@ -13,12 +13,12 @@ app = FastAPI()
 
 
 @app.get("/optional-str")
-async def read_optional_str(p: Annotated[Optional[str], Header()] = None):
+async def read_optional_str(p: Annotated[str | None, Header()] = None):
     return {"p": p}
 
 
 class HeaderModelOptionalStr(BaseModel):
-    p: Optional[str] = None
+    p: str | None = None
 
 
 @app.get("/model-optional-str")
@@ -74,13 +74,13 @@ def test_optional_str(path: str):
 
 @app.get("/optional-alias")
 async def read_optional_alias(
-    p: Annotated[Optional[str], Header(alias="p_alias")] = None,
+    p: Annotated[str | None, Header(alias="p_alias")] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalAlias(BaseModel):
-    p: Optional[str] = Field(None, alias="p_alias")
+    p: str | None = Field(None, alias="p_alias")
 
 
 @app.get("/model-optional-alias")
@@ -150,13 +150,13 @@ def test_optional_alias_by_alias(path: str):
 
 @app.get("/optional-validation-alias")
 def read_optional_validation_alias(
-    p: Annotated[Optional[str], Header(validation_alias="p_val_alias")] = None,
+    p: Annotated[str | None, Header(validation_alias="p_val_alias")] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalValidationAlias(BaseModel):
-    p: Optional[str] = Field(None, validation_alias="p_val_alias")
+    p: str | None = Field(None, validation_alias="p_val_alias")
 
 
 @app.get("/model-optional-validation-alias")
@@ -232,14 +232,14 @@ def test_optional_validation_alias_by_validation_alias(path: str):
 @app.get("/optional-alias-and-validation-alias")
 def read_optional_alias_and_validation_alias(
     p: Annotated[
-        Optional[str], Header(alias="p_alias", validation_alias="p_val_alias")
+        str | None, Header(alias="p_alias", validation_alias="p_val_alias")
     ] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalAliasAndValidationAlias(BaseModel):
-    p: Optional[str] = Field(None, alias="p_alias", validation_alias="p_val_alias")
+    p: str | None = Field(None, alias="p_alias", validation_alias="p_val_alias")
 
 
 @app.get("/model-optional-alias-and-validation-alias")
