@@ -3,6 +3,8 @@ from fastapi import FastAPI
 from fastapi.testclient import TestClient
 from inline_snapshot import snapshot
 
+from tests.utils import workdir_lock
+
 
 @pytest.fixture(name="app", scope="module")
 def get_app():
@@ -11,6 +13,7 @@ def get_app():
     yield app
 
 
+@workdir_lock
 def test_events(app: FastAPI):
     with TestClient(app) as client:
         response = client.get("/items/")
@@ -20,6 +23,7 @@ def test_events(app: FastAPI):
         assert "Application shutdown" in log.read()
 
 
+@workdir_lock
 def test_openapi_schema(app: FastAPI):
     with TestClient(app) as client:
         response = client.get("/openapi.json")
