@@ -16,7 +16,7 @@ from ...utils import needs_py310
     ],
 )
 def get_app(request: pytest.FixtureRequest):
-    mod = importlib.import_module(f"docs_src.websockets.{request.param}")
+    mod = importlib.import_module(f"docs_src.websockets_.{request.param}")
 
     return mod.app
 
